
//------------------------------------------------------------------------------------------------------------------- 
//******************************************-------------------------------****************************************** 
//                           ||Atomic Fission Grenade Launcher|| 
//**********************************-----------------------------------------------********************************** 
// 
// Lt Earthworm's 'Atomic Fission Grenade Launcher' (AFGL) 
// 
// 
// 
// List of datablocks: 
//         Sounds-- 
//            AFgrenadeActivateSound1      // Heard when the weapon mounts 
//            AFgrenadeActivateSound2      // Heard when the weapon mounts 
//            AFgrenadeIdleSound      // Heard when AFGL is idle 
//            AFgrenadeAftermathWind      // Heard after the explosion is gone 
//            AFgrenadeReloadSound      // Heard when the weapons loads a nuke 
//            AFgrenadeFireSound      // Heard when the weapon is fired 
// 
//         Particles-- 
//            AFGfireParticle         // Particle trail for projectile 
//            AFGdirtBlastParticle      // Blast of dirt on the ground when the AFG explodes 
//            AFGdirtSuckParticle      // Dirt sucked back into the explosion 
//            AFRingParticle         // Ring particles 
// 
//         Emitters-- 
//            AFGfireEmitter         // Emits AFGfireParticle particles 
//            AFGdirtBlastEmitter      // Emits AFFdirtBlastParticle particles 
//            AFGdirtSuckEmitter      // Emits AFGdirtSuckParticle particles 
//            AFBottomRingEmitter      // Emits AFRingParticle particles 
//            AFMidRingEmitter         // Emits AFRingParticle particles 
//            AFTopRingEmitter         // Emits AFRingParticle particles 
// 
//         Explosions-- 
//            AFgrenadeSubExplosion1      // Sub explosion for AFG projectile explosion 
//            AFgrenadeSubExplosion2      // Sub explosion for AFG projectile explosion 
//            AFgrenadeExplosion      // AFG projectile explosion 
//            AFstemSubExplosion1      // Stem sub explosion 
//            AFstemSubExplosion2      // Stem sub explosion 
//            AFstemExplosion         // Stem explosion 
//            AFtopSubExplosion1      // Sub explosion for top 
//            AFtopSubExplosion2      // Sub explosion for top 
//            AFtopExplosion         // Top explosion 
// 
//         Projectiles-- 
//            FissionGrenade         // Grenade shot out of the AFGL 
//            AFGLStemProjectile      // Stem projectile 
//            AFGLTopProjectile         // Top projectile 
// 
//         Images-- 
//            AFgrenadeLauncherImage      // Default image mounted in WeaponImage::onMount() 
//            AFgrenadeBoltBarrel1      // Extra image for spiffiness 
//            AFgrenadeBoltBarrel2      // Extra image for spiffiness 
//            AFgrenadeBolt         // Extra image for spiffiness 
//            AFgrenadePower         // Extra image for spiffiness 
// 
//         Items-- 
//            AFgrenadeLauncher         // Item reffered to in other files. 
// 
// 
//      Total count of datablocks: 34 
// 
// 
// List of functions: 
//         AFgrenadeLauncherImage::onMount(%this,%obj,%slot)      // Mounts extra images 
//         AFgrenadeLauncherImage::onUnmount(%this,%obj,%slot)      // Unmounts images 
//         AFgrenadeLauncherImage::onFire(%data, %obj, %slot)      // Unmounts AFgrenadeBolt 
//         FissionGrenade::onExplode(%data, %proj, %pos, %mod)      // Spawns stem 
//         AFGLStemProjectile::onExplode(%data, %proj, %pos, %mod)   // Spawns a stem or top projectile 
//         ShapeBase::shouldApplyImpulse(%data, %obj)         // Extra check for wind 
//         mountBolt(%obj)                        // Mounts AFgrenadeBolt 
//         SpawnEmitter(%EmissionDummy, %emitterData, %pos, %time)   // Spawns an emitter 
//         RadiusImpulse(%position, %radius, %impulse, %isInverse)   // Applies an impulse in a radius 
//         NuclearWinds(%position, %radius, %impulse, %times, %rad)   // Calls RadiusImpulse for wind effect 
// 
// List of misc things: 
//         $Nuke_Stem_Times      // Number of times the stem projectile explodes 
//         $Nuke_Stem_Min      // Minimum number of explosions for the stem 
//         $Nuke_Stem_Max      // Maximum number of explosions for the stem 
//------------------------------------------------------------------------------------------------------------------- 

$Nuke_Stem_Min = 15; 
$Nuke_Stem_Max = 20; 

//-------------------------------------- 
// Sounds 
//-------------------------------------- 

datablock AudioProfile(AFgrenadeActivateSound1) 
{ 
   filename    = "fx/vehicles/MPB_deploy.wav"; 
   description = AudioDefault3d; 
   preload = true; 
}; 

datablock AudioProfile(AFgrenadeActivateSound2) 
{ 
   filename    = "fx/vehicles/MPB_deploy_turret.wav"; 
   description = AudioDefault3d; 
   preload = true; 
}; 

datablock AudioProfile(AFgrenadeIdleSound) 
{ 
   filename    = "fx/armor/thrust_uw.wav";   // "fx/powered/generator_hum.wav" 
   description = CloseLooping3d; 
   preload = true; 
}; 

datablock AudioProfile(AFgrenadeAftermathWind) 
{ 
   filename    = "fx/environment/moaningwind1.wav"; 
   description = Audio2D; 
   preload = true; 
}; 

datablock AudioProfile(AFgrenadeReloadSound) 
{ 
   filename    = "fx/powered/turret_heavy_reload.wav"; 
   description = AudioDefault3d; 
   preload = true; 
}; 

datablock AudioProfile(AFgrenadeFireSound) 
{ 
   filename    = "fx/weapons/grenade_flash_explode.wav"; 
   description = AudioDefault3d; 
   preload = true; 
}; 

//-------------------------------------- 
// Particle Effects 
//-------------------------------------- 

//-------------------------- 
// Trail Effects 
//--------------- 

datablock ParticleData(AFGfireParticle) 
{ 
   dragCoeffiecient     = 5; 
   gravityCoefficient   = 0; 
   windCoefficient      = 0; 
   inheritedVelFactor   = 0.0; 
   constantAcceleration = 0; 

   lifetimeMS           = 2000;  
   lifetimeVarianceMS   = 0; 

   textureName          = "flareBase"; 

   colors[0]     = "1 0.7 0.1 1.0"; 
   colors[1]     = "1 0.7 0.1 0.8"; 
   colors[2]     = "1 0.7 0.1 0.0"; 
   sizes[0]      = 4; 
   sizes[1]      = 6; 
   sizes[2]      = 1; 
   times[0]      = 0.0; 
   times[1]      = 0.1; 
   times[2]      = 1.0; 
}; 

datablock ParticleEmitterData(AFGfireEmitter) 
{ 
   ejectionPeriodMS = 4; 
   periodVarianceMS = 0; 

   ejectionVelocity = 0.0; 
   velocityVariance = 0; 

   thetaMin         = 0; 
   thetaMax         = 0; 


   orientParticles  = False; 
   orientOnVelocity = False; 
   lifeTimeMS       = 0; 
   particles = "AFGfireParticle"; 
}; 

//-------------------------- 
// Dirt Effects 
//--------------- 

datablock ParticleData(AFGdirtBlastParticle) 
{ 
   dragCoeffiecient     = 0; 
   gravityCoefficient   = 0; 
   windCoefficient      = 0; 
   inheritedVelFactor   = 0.0; 
   constantAcceleration = -0.1; 

   spinRandomMin = -500; 
   spinRandomMax = 500; 

   lifetimeMS           = 15000;  
   lifetimeVarianceMS   = 5000; 

   useInvAlpha = true; 

   textureName          = "special/smoke/bigsmoke"; 

   colors[0]     = "0.8 0.6 0.4 0.5"; 
   colors[1]     = "0.8 0.6 0.4 0.2"; 
   colors[2]     = "0.8 0.6 0.4 0.0"; 
   sizes[0]      = 30; 
   sizes[1]      = 40; 
   sizes[2]      = 50; 
   times[0]      = 0.0; 
   times[1]      = 0.9; 
   times[2]      = 1.0; 
}; 

datablock ParticleEmitterData(AFGdirtBlastEmitter) 
{ 
   ejectionPeriodMS = 1; 
   periodVarianceMS = 0; 

   ejectionVelocity = 150; 
   velocityVariance = 70; 

   thetaMin         = 86; 
   thetaMax         = 90; 

   orientParticles  = False; 
   orientOnVelocity = False; 
   lifetimeMS       = 6000; 
   particles = "AFGdirtBlastParticle"; 
}; 

datablock ParticleData(AFGdirtSuckParticle) 
{ 
   dragCoeffiecient     = 0; 
   gravityCoefficient   = 0; 
   windCoefficient      = 0; 
   inheritedVelFactor   = 0.0; 
   constantAcceleration = -0.35; 

   spinRandomMin = -500; 
   spinRandomMax = 500; 

   lifetimeMS           = 6000;  
   lifetimeVarianceMS   = 3000; 

   useInvAlpha = true; 

   textureName          = "special/smoke/bigsmoke"; 

   colors[0]     = "0.8 0.6 0.4 0"; 
   colors[1]     = "0.8 0.6 0.4 0.4"; 
   colors[2]     = "0.8 0.6 0.4 0"; 
   sizes[0]      = 30; 
   sizes[1]      = 40; 
   sizes[2]      = 50; 
   times[0]      = 0.0; 
   times[1]      = 0.9; 
   times[2]      = 1.0; 
}; 

datablock ParticleEmitterData(AFGdirtSuckEmitter) 
{ 
   ejectionPeriodMS = 1; 
   periodVarianceMS = 0; 

   ejectionVelocity = 100; 
   velocityVariance = 45; 

   thetaMin         = 86; 
   thetaMax         = 90; 

   ejectionOffset = 600; 

   orientParticles  = False; 
   orientOnVelocity = False; 
   lifetimeMS       = 0; 
   particles = "AFGdirtSuckParticle"; 
}; 

//-------------------------- 
// Ring Effects 
//--------------- 

datablock ParticleData(AFRingParticle) 
{ 
   dragCoeffiecient     = 0; 
   gravityCoefficient   = 0; 
   windCoefficient      = 0; 
   inheritedVelFactor   = 0.0; 
   constantAcceleration = 0; 

   spinRandomMin = -100; 
   spinRandomMax = 100; 

   lifetimeMS           = 12000;  
   lifetimeVarianceMS   = 3000; 

   useInvAlpha = false; 

   textureName          = "particleTest"; 

   colors[0]     = "1 1 1 0"; 
   colors[1]     = "1 1 1 0.4"; 
   colors[2]     = "1 1 1 0"; 
   sizes[0]      = 25; 
   sizes[1]      = 30; 
   sizes[2]      = 35; 
   times[0]      = 0.0; 
   times[1]      = 0.5; 
   times[2]      = 1.0; 
}; 

datablock ParticleEmitterData(AFBottomRingEmitter) 
{ 
   ejectionPeriodMS = 8; 
   periodVarianceMS = 0; 

   ejectionVelocity = 0; 
   velocityVariance = 0; 

   thetaMin         = 86; 
   thetaMax         = 90; 

   ejectionOffset = 600; 

   orientParticles  = False; 
   orientOnVelocity = False; 
   particles = "AFRingParticle"; 
}; 

datablock ParticleEmitterData(AFMidRingEmitter) 
{ 
   ejectionPeriodMS = 8; 
   periodVarianceMS = 0; 

   ejectionVelocity = 0; 
   velocityVariance = 0; 

   thetaMin         = 86; 
   thetaMax         = 90; 

   ejectionOffset = 550; 

   orientParticles  = False; 
   orientOnVelocity = False; 
   particles = "AFRingParticle"; 
}; 

datablock ParticleEmitterData(AFTopRingEmitter) 
{ 
   ejectionPeriodMS = 8; 
   periodVarianceMS = 0; 

   ejectionVelocity = 0; 
   velocityVariance = 0; 

   thetaMin         = 86; 
   thetaMax         = 90; 

   ejectionOffset = 450; 

   orientParticles  = False; 
   orientOnVelocity = False; 
   particles = "AFRingParticle"; 
}; 

//-------------------------------------- 
// Projectile Explosion 
//-------------------------------------- 

datablock ExplosionData(AFgrenadeSubExplosion1) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   playSpeed = 0.08; 
   offset = 34; 

   sizes[0] = "60 80 60"; 
   sizes[1] = "70 70 60"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

datablock ExplosionData(AFgrenadeSubExplosion2) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   playSpeed = 0.05; 
   offset = 24; 

   sizes[0] = "80 80 80"; 
   sizes[1] = "80 80 80"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

datablock ExplosionData(AFgrenadeExplosion) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   subExplosion[0] = AFgrenadeSubExplosion1; 
   subExplosion[1] = AFgrenadeSubExplosion2; 

   playSpeed = 0.05; 

   emitter[0] = AFGdirtBlastEmitter; 

   sizes[0] = "90 90 90"; 
   sizes[1] = "90 90 90"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

//-------------------------------------- 
// Stem Explosion 
//-------------------------------------- 

datablock ExplosionData(AFstemSubExplosion1) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   playSpeed = 0.08; 
   offset = 10; 

   sizes[0] = "15 15 15"; 
   sizes[1] = "17 17 17"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

datablock ExplosionData(AFstemSubExplosion2) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   playSpeed = 0.05; 
   offset = 13; 

   sizes[0] = "17 19 17"; 
   sizes[1] = "18 18 18"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

datablock ExplosionData(AFstemExplosion) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   subExplosion[0] = AFstemSubExplosion1; 
   subExplosion[1] = AFstemSubExplosion2; 

   playSpeed = 0.05; 

   sizes[0] = "16 16 16"; 
   sizes[1] = "20 20 20"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

//-------------------------------------- 
// Top Explosion 
//-------------------------------------- 

datablock ExplosionData(AFtopSubExplosion1) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   playSpeed = 0.08; 
   offset = 34; 

   sizes[0] = "100 100 100"; 
   sizes[1] = "90 90 90"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

datablock ExplosionData(AFtopSubExplosion2) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   playSpeed = 0.05; 
   offset = 24; 

   sizes[0] = "80 120 100"; 
   sizes[1] = "100 100 100"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

datablock ExplosionData(AFtopExplosion) 
{ 
   explosionShape = "effect_plasma_explosion.dts"; 
   //soundProfile   = plasmaExpSound; 
   faceViewer = true; 

   subExplosion[0] = AFtopSubExplosion1; 
   subExplosion[1] = AFtopSubExplosion2; 

   playSpeed = 0.05; 

   sizes[0] = "110 110 110"; 
   sizes[1] = "110 110 110"; 
   times[0] = 0.0; 
   times[1] = 1; 
}; 

//-------------------------------------- 
// Image Projectile 
//-------------------------------------- 
datablock BombProjectileData(FissionGrenade) 
{ 
   projectileShapeName = "turret_muzzlepoint.dts"; 
   directDamage        = 0.0; 
   hasDamageRadius     = true; 
   indirectDamage      = 30; 
   damageRadius        = 500; 
   radiusDamageType    = $DamageType::Redeemer; 
   kickBackStrength    = 0; 
   bubbleEmitTime      = 1.0; 

   sound               = GrenadeProjectileSound; 
   explosion           = "AFgrenadeExplosion"; 
   underwaterExplosion = "UnderwaterGrenadeExplosion"; 
   velInheritFactor    = 0.5; 
   splash              = GrenadeSplash; 

   baseEmitter         = "AFGfireEmitter"; 
   emitterDelay        = -1; 

   grenadeElasticity = 0.6; 
   grenadeFriction   = 0.5; 
   muzzleVelocity    = 300; 
   gravityMod        = 5; 
   drag = 0; 
}; 

//-------------------------------------- 
// Stem Projectile 
//-------------------------------------- 
datablock LinearProjectileData(AFGLStemProjectile) 
{ 
   projectileShapeName = "turret_muzzlepoint.dts"; 
   directDamage        = 0.0; 
   hasDamageRadius     = true; 
   indirectDamage      = 1.5; 
   damageRadius        = 200; 
   radiusDamageType    = $DamageType::Redeemer; 
   kickBackStrength    = 0; 
   bubbleEmitTime      = 1.0; 

   sound               = GrenadeProjectileSound; 
   explosion           = "AFstemExplosion"; 
   velInheritFactor    = 0.5; 
   splash              = GrenadeSplash; 

   lifeTimeMS      = 55; 
   explodeOnDeath       = true; 

   dryVelocity = 550; 

   drag = 0; 
}; 

//-------------------------------------- 
// Top Projectile 
//-------------------------------------- 
datablock LinearProjectileData(AFGLTopProjectile) 
{ 
   projectileShapeName = "turret_muzzlepoint.dts"; 
   directDamage        = 0.0; 
   hasDamageRadius     = true; 
   indirectDamage      = 3; 
   damageRadius        = 500; 
   radiusDamageType    = $DamageType::Redeemer; 
   kickBackStrength    = 0; 
   bubbleEmitTime      = 1.0; 

   sound               = GrenadeProjectileSound; 
   explosion           = "AFtopExplosion"; 
   velInheritFactor    = 0.5; 
   splash              = GrenadeSplash; 

   lifeTimeMS      = 100; 
   explodeOnDeath       = true; 

   dryVelocity = 500; 

   drag = 0; 
}; 

//-------------------------------------- 
// Item and Image 
//-------------------------------------- 
datablock ItemData(AFgrenadeLauncher) 
{ 
   className    = Weapon; 
   catagory     = "Spawn Items"; 
   shapeFile    = "weapon_mortar.dts"; 
   image        = AFgrenadeLauncherImage; 
   mass         = 1; 
   elasticity   = 0.2; 
   friction     = 0.6; 
   pickupRadius = 2; 
   pickUpName = "an Atomic Fission Grenade Launcher"; 

   computeCRC = true; 

}; 

datablock ShapeBaseImageData(AFgrenadeLauncherImage) 
{ 
   className = WeaponImage; 
   shapeFile = "turret_tank_barrelmortar.dts"; 
   item = AFgrenadeLauncher; 
   projectile = FissionGrenade; 
   projectileType = BombProjectile; 
   offset = "0.2 0 -0.1"; 

   usesEnergy = true; 
   fireEnergy = 0; 
   minEnergy = 0; 

   stateName[0]                     = "Activate"; 
   stateTransitionOnTimeout[0]      = "Activate2"; 
   stateSound[0]                    = AFgrenadeActivateSound1; 
   stateTimeoutValue[0]             = 0.25; 
   stateSequence[0]                 = "Activate"; 

   stateName[1]                     = "ActivateReady"; 
   stateTransitionOnLoaded[1]       = "Ready"; 
   stateTransitionOnNoAmmo[1]       = "NoAmmo"; 

   stateName[2]                     = "Ready"; 
   stateTransitionOnNoAmmo[2]       = "NoAmmo"; 
   stateTransitionOnTriggerDown[2]  = "CheckWet"; 
   stateSound[2]                    = AFgrenadeIdleSound; 

   stateName[3]                     = "Fire"; 
   stateSound[3]                    = AFgrenadeFireSound; 
   stateTransitionOnTimeout[3]      = "Reload"; 
   stateTimeoutValue[3]             = 0.25; 
   stateFire[3]                     = true; 
   stateAllowImageChange[3]         = false; 
   stateSequence[3]                 = "Fire"; 
   stateScript[3]                   = "onFire"; 

   stateName[4]                     = "Reload"; 
   stateSound[4]                    = AFgrenadeReloadSound; 
   stateTransitionOnTimeout[4]      = "Ready"; 
   stateTimeoutValue[4]             = 0.25; 
   stateAllowImageChange[4]         = false; 

   stateName[5]                     = "CheckWet"; 
   stateTransitionOnWet[5]          = "DryFire"; 
   stateTransitionOnNotWet[5]       = "Fire"; 
    
   stateName[6]                     = "NoAmmo"; 
   stateTransitionOnAmmo[6]         = "Reload"; 
   stateTransitionOnTriggerDown[6]  = "DryFire"; 
   stateSequence[6]                 = "NoAmmo"; 
    
   stateName[7]                     = "DryFire"; 
   stateSound[7]                    = SniperRifleDryFireSound; 
   stateTimeoutValue[7]             = 0.25; 
   stateTransitionOnTimeout[7]      = "Ready"; 

   stateName[8]            = "Activate2"; 
   stateSound[8]                    = AFgrenadeActivateSound2; 
   stateTransitionOnTimeout[8]      = "LoadSound"; 
   stateTimeoutValue[8]             = 0.25; 

   stateName[9]            = "LoadSound"; 
   stateSound[9]            = "AFgrenadeReloadSound"; 
   stateTransitionOnTimeout[9]      = "ActivateReady"; 
   stateTimeoutValue[9]             = 0.25; 
}; 

datablock ShapeBaseImageData(AFgrenadeBoltBarrel1) 
{ 
   className = WeaponImage; 
   shapeFile = "pack_upgrade_energy.dts"; 
   offset = "0.4 1.2 0.2"; 
   rotation = "0 0 0 0"; 
}; 

datablock ShapeBaseImageData(AFgrenadeBoltBarrel2) 
{ 
   className = WeaponImage; 
   shapeFile = "pack_upgrade_energy.dts"; 
   offset = "0.4 2 0.2"; 
   rotation = "0 0 1 180"; 
}; 

datablock ShapeBaseImageData(AFgrenadeBolt) 
{ 
   className = WeaponImage; 
   shapeFile = "energy_bolt.dts"; 
   offset = "0.4 2 0"; 
   rotation = "0 0 0 0"; 
}; 

datablock ShapeBaseImageData(AFgrenadePower) 
{ 
   className = WeaponImage; 
   shapeFile = "solarpanel.dts"; 
   offset = "0.2 0 0.1"; 
   rotation = "1 0 0 -90"; 
}; 

datablock LinearProjectileData(AFInstantExplosion)
{
projectileShapeName = "turret_muzzlepoint.dts";
scale               = "0.1 0.1 0.1";
faceViewer          = false;
directDamage        = 0;
hasDamageRadius     = true;
indirectDamage      = 30;//2.2
damageRadius        = 500;
radiusDamageType    = $DamageType::Redeemer;
   explosion           = "AFgrenadeExplosion"; 
sound               = GrenadeProjectileSound; 
dryVelocity       = 0.0001;
wetVelocity       = 0.00001;
velInheritFactor  = 0.0;
lifetimeMS        = 0.00000001;
explodeOnDeath    = true;
   explodeOnWaterImpact      = false;
reflectOnWaterImpactAngle = 0.0;
explodeOnWaterImpact      = true;
deflectionOnWaterImpact   = 0.0;
   activateDelayMS = 200;
   fizzleUnderwaterMS        = 5000;
};



function AFgrenadeLauncherImage::onMount(%this,%obj,%slot) 
{ 
   Parent::onMount(%this, %obj, %slot); 
	CommandToClient(%obj.client, 'BottomPrint', "<spush><font:Sui Generis:14>>>>Atomic Fission Grenade Launcher<<<<spop>\n<spush><font:Arial:14>Datablock & Visual Friendly Nuke.\nCoded by Lt. Earthworm<spop>", 3, 3 );
   %obj.mountImage(AFgrenadeBoltBarrel1, $AuxiliarySlot); 
   %obj.mountImage(AFgrenadeBoltBarrel2, 4); 
   schedule(800, 0, "mountBolt", %obj);           //%obj.mountImage(AFgrenadeBolt, $WeaponSlot3); 
   %obj.mountImage(AFgrenadePower, 6); 
} 

function AFgrenadeLauncherImage::onUnmount(%this,%obj,%slot) 
{ 
   %obj.unmountImage($AuxiliarySlot); 
   %obj.unmountImage(4); 
   %obj.unmountImage(5); 
   %obj.unmountImage(6); 
   Parent::onUnmount(%this, %obj, %slot); 
} 

function AFgrenadeLauncherImage::onFire(%data, %obj, %slot) 
{ 
   %p = Parent::onFire(%data, %obj, %slot); 
   AiGrenadeThrown(%p); 
   %obj.unmountImage(5); 
      %obj.client.setWeaponsHudActive(%data.item); 
   schedule(600,0, "mountBolt", %obj); 
} 

function AFInstantExplosion::onExplode(%data, %proj, %pos, %mod) 
{ 
   $Nuke_Stem_Times = getRandom($Nuke_Stem_Min, $Nuke_Stem_Max); 
      RadiusExplosion(%proj, %pos, %data.damageRadius, %data.indirectDamage, %data.kickBackStrength, %proj.sourceObject, %data.radiusDamageType); 
   %stem = new LinearProjectile(){ 
            datablock = AFGLStemProjectile; 
            initialPosition = %pos; 
            initialDirection = "0 0 1"; 
            sourceObject = %proj.sourceObject; 
         }; 
   MissionCleanup.add(%stem); 
   %stem.expTimes = 0; 
   %stem.MaxTimes = $Nuke_Stem_Times; 
   %stem.StartPos = %pos; 
   schedule(7500,0, "SpawnEmitter", defaultEmissionDummy, AFGdirtSuckEmitter, %pos, 10000); 
   NuclearWinds(vectorAdd(%pos, "0 0 10"), 1500, 5000, 5000/120); 
} 

function FissionGrenade::onExplode(%data, %proj, %pos, %mod) 
{ 
   $Nuke_Stem_Times = getRandom($Nuke_Stem_Min, $Nuke_Stem_Max); 
      RadiusExplosion(%proj, %pos, %data.damageRadius, %data.indirectDamage, %data.kickBackStrength, %proj.sourceObject, %data.radiusDamageType); 
   %stem = new LinearProjectile(){ 
            datablock = AFGLStemProjectile; 
            initialPosition = %pos; 
            initialDirection = "0 0 1"; 
            sourceObject = %proj.sourceObject; 
         }; 
   MissionCleanup.add(%stem); 
   %stem.expTimes = 0; 
   %stem.MaxTimes = $Nuke_Stem_Times; 
   %stem.StartPos = %pos; 
   schedule(7500,0, "SpawnEmitter", defaultEmissionDummy, AFGdirtSuckEmitter, %pos, 10000); 
   NuclearWinds(vectorAdd(%pos, "0 0 10"), 1500, 5000, 5000/120); 
} 

function AFGLStemProjectile::onExplode(%data, %proj, %pos, %mod) 
{ 
      RadiusExplosion(%proj, %pos, %data.damageRadius, %data.indirectDamage, %data.kickBackStrength, %proj.sourceObject, %data.radiusDamageType); 
   if(%proj.expTimes <= %proj.MaxTimes) 
   { 
      %Max = %proj.MaxTimes; 
      %HalfTest = mFloor(%Max/2); 
      %FirstTest = mFloor(%Max/4); 

      %vector = %proj.initialDirection; 
      %x = (getRandom() - 0.5) * 2 * 3.1415926 * 60/1000; 
      %y = (getRandom() - 0.5) * 2 * 3.1415926 * 60/1000; 
      %z = (getRandom() - 0.5) * 2 * 3.1415926 * 60/1000; 
      %mat = MatrixCreateFromEuler(%x @ " " @ %y @ " " @ %z); 
      %vector = MatrixMulVector(%mat, %vector); 

      %stem = new LinearProjectile(){ 
               datablock = AFGLStemProjectile; 
               initialPosition = %pos; 
               initialDirection = %vector; 
               sourceObject = %proj.sourceObject; 
            }; 
      MissionCleanup.add(%stem); 
      %stem.expTimes = %proj.expTimes+1; 
      %stem.MaxTimes = %proj.MaxTimes; 
      %stem.StartPos = %proj.StartPos; 
      %z = getWords(%pos, 2, 2); 
      %x = getWords(%proj.StartPos, 0, 0); 
      %y = getWords(%proj.StartPos, 1, 1); 
      if(%proj.expTimes == %FirstTest || %proj.expTimes == %HalfTest) 
         if(%proj.expTimes == %FirstTest) 
            SpawnEmitter(defaultEmissionDummy, AFBottomRingEmitter, %x SPC %y SPC %z, 15000); 
         else 
            SpawnEmitter(defaultEmissionDummy, AFMidRingEmitter, %x SPC %y SPC %z, 15000); 
   } 
   else 
   { 
      %top = new LinearProjectile(){ 
               datablock = AFGLTopProjectile; 
               initialPosition = %pos; 
               initialDirection = "0 0 1"; 
               sourceObject = %proj.sourceObject; 
            }; 
      MissionCleanup.add(%top); 
      %z = getWords(%pos, 2, 2); 
      %x = getWords(%proj.StartPos, 0, 0); 
      %y = getWords(%proj.StartPos, 1, 1); 
      SpawnEmitter(defaultEmissionDummy, AFTopRingEmitter, %x SPC %y SPC %z, 15000); 
   } 
} 

function mountBolt(%obj) 
{ 
   if(%obj.getMountedImage(0).item.image $= AFgrenadeLauncherImage)   // Just to make sure 
      %obj.mountImage(AFgrenadeBolt, 5); 
} 

function SpawnEmitter(%EmissionDummy, %emitterData, %pos, %time) 
{ 
   if(%EmissionDummy $= "") 
      %EmissionDummy = defaultEmissionDummy; 
   %emitter = new ParticleEmissionDummy() 
      { 
      position = %pos; 
      scale = "1 1 1"; 
      dataBlock = %EmissionDummy;      // valid dummies are default, halftime, and doubletime 
      emitter = %emitterData; 
      velocity = "1"; 
      }; 
   MissionCleanup.add(%emitter); 
   if(%time) 
      %emitter.schedule(%time, "delete"); 
   return %emitter; 
} 

function RadiusImpulse(%position, %radius, %impulse, %isInverse) 
{ 
   InitContainerRadiusSearch(%position, %radius, $TypeMasks::PlayerObjectType      | 
                                                 $TypeMasks::VehicleObjectType); 

   %numTargets = 0; 
   while ((%targetObject = containerSearchNext()) != 0) 
   { 
      %dist = containerSearchCurrRadDamageDist(); 

      if (%dist > %radius) 
         continue; 

      if (%targetObject.isMounted()) 
      { 
         %mount = %targetObject.getObjectMount(); 
         %found = -1; 
         for (%i = 0; %i < %mount.getDataBlock().numMountPoints; %i++) 
         { 
            if (%mount.getMountNodeObject(%i) == %targetObject) 
            { 
               %found = %i; 
               break; 
            } 
         } 
      
         if (%found != -1) 
         { 
            if (%mount.getDataBlock().isProtectedMountPoint[%found]) 
            { 
               continue; 
            } 
         } 
      } 
      %data = %targetObject.getDataBlock(); 
      %className = %data.className; 
   //if(%data.shouldApplyImpulse() || %className $= WheeledVehicledata || %className $= FlyingVehicleData || %className $= HoverVehicleData) 
   //{ 
         %targets[%numTargets]     = %targetObject; 
         %targetDists[%numTargets] = %dist; 
         %numTargets++; 
   //} 
   } 
   for (%i = 0; %i < %numTargets; %i++) 
   { 
      %targetObject = %targets[%i]; 
      %dist = %targetDists[%i]; 
      %coverage = calcExplosionCoverage(%position, %targetObject, 
                                        ($TypeMasks::InteriorObjectType | 
                                         $TypeMasks::TerrainObjectType | 
                                         $TypeMasks::ForceFieldObjectType | 
                                         $TypeMasks::VehicleObjectType)); 
      if (%coverage == 0) 
         continue; 
      %amount = (1.0 - ((%dist / %radius) * 0.88)) * %coverage * %impulse; 
   if(%isInverse) 
      %vect = vectorScale(vectorNormalize(vectorSub(%targetObject.getPosition(), %position)), %amount*-1); 
   else 
      %vect = vectorScale(vectorNormalize(vectorSub(%targetObject.getPosition(), %position)), %amount); 
      %data = %targetObject.getDataBlock(); 
      %className = %data.className; 

   //if(%targetObject.getDatablock().getClassName() $= "WheeledVehicleData") 
      //%vec = vectorScale(%vec, 1000); 
   %vec = vectorScale(%vec, %targetObject.getDatablock().mass); 
   %targetObject.applyImpulse(%position, %vect); 
   } 
} 

function ShapeBase::shouldApplyImpulse(%data, %obj) 
{ 
   return false; 
} 

function NuclearWinds(%position, %radius, %impulse, %times, %rad) 
{
	if (!$ElecMod::AtomicNuke::Wind)
		return;
   if(%times <= 150) 
   { 
      RadiusImpulse(%position, %rad, %impulse); 
      %rad += %radius/120; 
      schedule(100, 0, "NuclearWinds", %position, %radius, %impulse, %times+1, %rad); 
   } 
   else if(%times > 150 &&  %times <= 300) 
   { 
      RadiusImpulse(%position, %radius, %impulse, 1); 
      %rad -= %radius/120; 
      schedule(100, 0, "NuclearWinds", %position, %radius, %impulse, %times+1, %rad); 
   } 
   else 
   { 
      serverPlay2D(AFgrenadeAftermathWind); 
      serverPlay2D(AFgrenadeAftermathWind); 
   } 
}